/****************************************************************************
 *
 * HAMEG driver include file
 *
 ****************************************************************************/

#ifndef __HMF2500_HEADER
#define __HMF2500_HEADER

#include "rsidr_core.h"
#include "hmf2500_attributes.h"
#include "hmf2500_utility.h"

#include <string.h>
#include <stdlib.h>
#include <stdio.h>

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/*****************************************************************************
 *- Useful Macros & Constants -----------------------------------------------*
 *****************************************************************************/

#define VI_WARN_NSUP_ID_QUERY     (          0x3FFC0101L)
#define VI_WARN_NSUP_RESET        (          0x3FFC0102L)
#define VI_WARN_NSUP_SELF_TEST    (          0x3FFC0103L)
#define VI_WARN_NSUP_ERROR_QUERY  (          0x3FFC0104L)
#define VI_WARN_NSUP_REV_QUERY    (          0x3FFC0105L)

#define VI_ERROR_PARAMETER1       (_VI_ERROR+0x3FFC0001L)
#define VI_ERROR_PARAMETER2       (_VI_ERROR+0x3FFC0002L)
#define VI_ERROR_PARAMETER3       (_VI_ERROR+0x3FFC0003L)
#define VI_ERROR_PARAMETER4       (_VI_ERROR+0x3FFC0004L)
#define VI_ERROR_PARAMETER5       (_VI_ERROR+0x3FFC0005L)
#define VI_ERROR_PARAMETER6       (_VI_ERROR+0x3FFC0006L)
#define VI_ERROR_PARAMETER7       (_VI_ERROR+0x3FFC0007L)
#define VI_ERROR_PARAMETER8       (_VI_ERROR+0x3FFC0008L)
#define VI_ERROR_FAIL_ID_QUERY    (_VI_ERROR+0x3FFC0011L)
#define VI_ERROR_INV_RESPONSE     (_VI_ERROR+0x3FFC0012L)

#define VI_ERROR_INSTR_FILE_OPEN                (_VI_ERROR+0x3FFC0800L)
#define VI_ERROR_INSTR_FILE_WRITE               (_VI_ERROR+0x3FFC0801L)
#define VI_ERROR_INSTR_INTERPRETING_RESPONSE    (_VI_ERROR+0x3FFC0803L)
#define VI_ERROR_INSTR_PARAMETER8               (_VI_ERROR+0x3FFC0808L)
#define VI_ERROR_INSTR_PARAMETER9               (_VI_ERROR+0x3FFC0809L)
#define VI_ERROR_INSTR_PARAMETER10              (_VI_ERROR+0x3FFC080AL)
#define VI_ERROR_INSTR_PARAMETER11              (_VI_ERROR+0x3FFC080BL)
#define VI_ERROR_INSTR_PARAMETER12              (_VI_ERROR+0x3FFC080CL)
#define VI_ERROR_INSTR_PARAMETER13              (_VI_ERROR+0x3FFC080DL)
#define VI_ERROR_INSTR_PARAMETER14              (_VI_ERROR+0x3FFC080EL)
#define VI_ERROR_INSTR_PARAMETER15              (_VI_ERROR+0x3FFC080FL)

#define HMF2500_SIMULATION_ID_QUERY      "HAMEG,HMF2500,123456/789,1.23"  /* Default definition of ID Query Response for simulation */
#define HMF2500_VALID_ID_RESPONSE_STRING "HAMEG"      /* Valid response for identification query */
#define HMF2500_SIMULATION_OPT_QUERY     ""      /* Simulated response for *OPT? command */

#define HMF2500_IO_BUFFER_SIZE           1024L   /* I/O buffer size */
#define HMF2500_OPC_TIMEOUT              5000L   /* Maximum time to wait for OPC in milliseconds */
#define IEEE_488_2_ERROR_MASK             0x3C    /* 488.2 Event Status Register (ESR) Bits */
//#define IEEE_488_2_ERROR_MASK             0x4    /* 488.2 STB Bits */   
#define IEEE_488_2_ESE_MASK               0x3D    /* 488.2 Event Status Register (ESE) Bits */


/****************************************************************************
 *----------------- Instrument Driver Revision Information -----------------*
 ****************************************************************************/

/* Class Driver Identification */

#define HMF2500_CLASS_DRIVER_DESCRIPTION           ""
#define HMF2500_CLASS_DRIVER_PREFIX                ""
#define HMF2500_CLASS_DRIVER_VENDOR                ""
#define HMF2500_CLASS_DRIVER_REVISION              ""
#define HMF2500_CLASS_SPEC_MAJOR_VERSION           1L    /* Class specification major version */
#define HMF2500_CLASS_SPEC_MINOR_VERSION           0L    /* Class specification minor version */

/* Driver Identification */

#define HMF2500_SPECIFIC_DRIVER_DESCRIPTION        ""
#define HMF2500_SPECIFIC_DRIVER_PREFIX             "HMF2500"
#define HMF2500_SPECIFIC_DRIVER_LOCATOR            ""
#define HMF2500_SPECIFIC_DRIVER_VENDOR             ""
#define HMF2500_MAJOR_VERSION                      1L    /* Instrument driver major version          */
#define HMF2500_MINOR_VERSION                      0L   /* Instrument driver minor version          */
#define HMF2500_MINOR_MINOR_VERSION                0L    /* Instrument driver minor minor version    */

/* Driver Capabilities */          

#define HMF2500_SUPPORTED_INSTRUMENT_MODELS        ""    /* Instrument driver supported model(s)     */
#define HMF2500_GROUP_CAPABILITIES                 ""
#define HMF2500_FUNCTION_CAPABILITIES              ""

/****************************************************************************
 *------------------------------ Useful Macros -----------------------------*
 ****************************************************************************/


/****************************************************************************
 *---------------------------- Attribute Defines ---------------------------*
 ****************************************************************************/

    /*- Inherent Instrument Specific Attributes ----------------------------*/

        /* User Options 

#define HMF2500_ATTR_RANGE_CHECK                                           RS_ATTR_RANGE_CHECK                                     // ViBoolean
#define HMF2500_ATTR_QUERY_INSTRUMENT_STATUS                               RS_ATTR_QUERY_INSTRUMENT_STATUS                         // ViBoolean
#define HMF2500_ATTR_CACHE                                                 RS_ATTR_CACHE                                           // ViBoolean
#define HMF2500_ATTR_SIMULATE                                              RS_ATTR_SIMULATE                                        // ViBoolean 
#define HMF2500_ATTR_RECORD_COERCIONS                                      RS_ATTR_RECORD_COERCIONS                                // ViBoolean 
#define HMF2500_ATTR_INTERCHANGE_CHECK                                     RS_ATTR_INTERCHANGE_CHECK                               // ViBoolean 
#define HMF2500_ATTR_SPY                                                   RS_ATTR_SPY                                             // ViBoolean 
#define HMF2500_ATTR_USE_SPECIFIC_SIMULATION                               RS_ATTR_USE_SPECIFIC_SIMULATION                         // ViBoolean 

        /* Class Driver Identification 

#define HMF2500_ATTR_CLASS_DRIVER_DESCRIPTION                              RS_ATTR_CLASS_DRIVER_DESCRIPTION                        // ViString, read-only
#define HMF2500_ATTR_CLASS_DRIVER_PREFIX                                   RS_ATTR_CLASS_DRIVER_PREFIX                             // ViString, read-only
#define HMF2500_ATTR_CLASS_DRIVER_VENDOR                                   RS_ATTR_CLASS_DRIVER_VENDOR                             // ViString, read-only
#define HMF2500_ATTR_CLASS_DRIVER_REVISION                                 RS_ATTR_CLASS_DRIVER_REVISION                           // ViString, read-only
#define HMF2500_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION                 RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION           // ViInt32,  read-only 
#define HMF2500_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION                 RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION           // ViInt32,  read-only 

        /* Driver Identification 

#define HMF2500_ATTR_SPECIFIC_DRIVER_DESCRIPTION                           RS_ATTR_SPECIFIC_DRIVER_DESCRIPTION                     // ViString, read-only
#define HMF2500_ATTR_SPECIFIC_DRIVER_PREFIX                                RS_ATTR_SPECIFIC_DRIVER_PREFIX                          // ViString, read-only
#define HMF2500_ATTR_SPECIFIC_DRIVER_LOCATOR                               RS_ATTR_SPECIFIC_DRIVER_LOCATOR                         // ViString, read-only
#define HMF2500_ATTR_SPECIFIC_DRIVER_VENDOR                                RS_ATTR_SPECIFIC_DRIVER_VENDOR                          // ViString, read-only
#define HMF2500_ATTR_SPECIFIC_DRIVER_REVISION                              RS_ATTR_SPECIFIC_DRIVER_REVISION                        // ViString, read-only
#define HMF2500_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION              RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION        // ViInt32,  read-only 
#define HMF2500_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION              RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION        // ViInt32,  read-only 

        /* Driver Capabilities 

#define HMF2500_ATTR_SUPPORTED_INSTRUMENT_MODELS                           RS_ATTR_SUPPORTED_INSTRUMENT_MODELS                     // ViString, read-only
#define HMF2500_ATTR_GROUP_CAPABILITIES                                    RS_ATTR_GROUP_CAPABILITIES                              // ViString, read-only
#define HMF2500_ATTR_FUNCTION_CAPABILITIES                                 RS_ATTR_FUNCTION_CAPABILITIES                           // ViString, read-only
#define HMF2500_ATTR_CHANNEL_COUNT                                         RS_ATTR_CHANNEL_COUNT                                   // ViInt32,  read-only 

        /* Driver Setup 

#define HMF2500_ATTR_DRIVER_SETUP                                          RS_ATTR_DRIVER_SETUP                                    /* ViString            */

        /* Instrument Identification 

#define HMF2500_ATTR_INSTRUMENT_MANUFACTURER                               RS_ATTR_INSTRUMENT_MANUFACTURER                         // ViString, read-only
#define HMF2500_ATTR_INSTRUMENT_MODEL                                      RS_ATTR_INSTRUMENT_MODEL                                // ViString, read-only
#define HMF2500_ATTR_INSTRUMENT_FIRMWARE_REVISION                          RS_ATTR_INSTRUMENT_FIRMWARE_REVISION                    // ViString, read-only

        /* Advanced Session Information 

#define HMF2500_ATTR_IO_RESOURCE_DESCRIPTOR                                RS_ATTR_IO_RESOURCE_DESCRIPTOR                          // ViString, read-only
#define HMF2500_ATTR_LOGICAL_NAME                                          RS_ATTR_LOGICAL_NAME                                    // ViString, read-only

    /*- Instrument-Specific Attributes -------------------------------------*/

//#define HMF2500_ATTR_ID_QUERY_RESPONSE                                     (RS_SPECIFIC_PUBLIC_ATTR_BASE + 1L)                     /* ViString (Read Only)              */

/* BEGIN GENERATE */
#define HMF2500_ATTR_FREQUENCY                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 62
#define HMF2500_ATTR_PERIOD                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1
#define HMF2500_ATTR_POWER_LEVEL                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2
#define HMF2500_ATTR_POWER_LEVEL_WITH_OFFSET                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 3
#define HMF2500_ATTR_POWER_LEVEL_OFFSET_ENABLED                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 4
#define HMF2500_ATTR_POWER_LEVEL_OFFSET                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 5
#define HMF2500_ATTR_OUTPUT_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 6
#define HMF2500_ATTR_OUTPUT_FUNCTION                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 7
#define HMF2500_ATTR_AMPLITUDE_UNIT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 8
#define HMF2500_ATTR_OUTPUT_LOAD                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 9
#define HMF2500_ATTR_OUTPUT_POLARITY                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 10
#define HMF2500_ATTR_SQUARE_DUTY_CYCLE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 11
#define HMF2500_ATTR_SQUARE_WIDTH                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 63
#define HMF2500_ATTR_RAMP_SYMMETRY                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 12
#define HMF2500_ATTR_RAMP_EDGE_TIME                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 64
#define HMF2500_ATTR_PULSE_DUTY_CYCLE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 13
#define HMF2500_ATTR_PULSE_WIDTH                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 14
#define HMF2500_ATTR_PULSE_EDGE_TIME                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 15
#define HMF2500_ATTR_TRIGGER_ENABLED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 16
#define HMF2500_ATTR_TRIGGER_SOURCE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 17
#define HMF2500_ATTR_TRIGGER_SLOPE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 66
#define HMF2500_ATTR_OUTPUT_TRIGGER_SLOPE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 67
#define HMF2500_ATTR_MODULATION_SHAPE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 19
#define HMF2500_ATTR_AM_ENABLED                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 20
#define HMF2500_ATTR_AM_SOURCE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 21
#define HMF2500_ATTR_AM_DEPTH                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 22
#define HMF2500_ATTR_FM_ENABLED                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 23
#define HMF2500_ATTR_FM_SOURCE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 24
#define HMF2500_ATTR_FM_DEVIATION                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 25
#define HMF2500_ATTR_PM_ENABLED                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 26
#define HMF2500_ATTR_PM_SOURCE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 27
#define HMF2500_ATTR_PM_DEVIATION                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 28
#define HMF2500_ATTR_PULSE_ENABLED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 29
#define HMF2500_ATTR_PULSE_SOURCE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 30
#define HMF2500_ATTR_PULSE_MODULATION_DUTY_CYCLE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 31
#define HMF2500_ATTR_PULSE_INTERNAL_FREQUENCY                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 32
#define HMF2500_ATTR_FSK_ENABLED                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 33
#define HMF2500_ATTR_FSK_SOURCE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 34
#define HMF2500_ATTR_FSK_DUTY_CYCLE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 35
#define HMF2500_ATTR_FSK_FREQUENCY                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 36
#define HMF2500_ATTR_FSK_HOP                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 37
#define HMF2500_ATTR_SWEEP_ENABLED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 38
#define HMF2500_ATTR_SWEEP_FREQUENCY                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 39
#define HMF2500_ATTR_SWEEP_SPACING                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 40
#define HMF2500_ATTR_SWEEP_TIME                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 41
#define HMF2500_ATTR_SWEEP_MARKER_ENABLED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 42
#define HMF2500_ATTR_SWEEP_MARKER_FREQUENCY                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 43
#define HMF2500_ATTR_SWEEP_MARKER_STYLE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 68
#define HMF2500_ATTR_BURST_ENABLED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 44
#define HMF2500_ATTR_BURST_MODE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 45
#define HMF2500_ATTR_BURST_N_CYCLES                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 46
#define HMF2500_ATTR_BURST_INTERNAL_PERIOD                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 47
#define HMF2500_ATTR_BURST_PHASE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 48
#define HMF2500_ATTR_DISPLAY_TRACE_ENABLE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 69
#define HMF2500_ATTR_DISPLAY_TRACE_INTENSITY                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 70
#define HMF2500_ATTR_DISPLAY_GRID                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 71
#define HMF2500_ATTR_DISPLAY_LED_BRIGHTNESS                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 72
#define HMF2500_ATTR_DISPLAY_BACKLIGHT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 82
#define HMF2500_ATTR_ARB_FUNCTION                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 53
#define HMF2500_ATTR_DATA_SAVE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 76
#define HMF2500_ATTR_HARDCOPY_FORMAT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 73
#define HMF2500_ATTR_QUERY_HARDCOPY_SIZE_X                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 74
#define HMF2500_ATTR_QUERY_HARDCOPY_SIZE_Y                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 75
#define HMF2500_ATTR_ID_QUERY_RESPONSE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 54
#define HMF2500_ATTR_SYSTEM_REFERENCE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 55
#define HMF2500_ATTR_SYSTEM_SOUND_ERROR_BEEPER                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 83
#define HMF2500_ATTR_SYSTEM_SOUND_CONTROL_BEEPER                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 84
#define HMF2500_ATTR_RESET                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 59
#define HMF2500_ATTR_SYSTEM_ERROR                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 60
#define HMF2500_ATTR_SYSTEM_SERIAL_NUMBER                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 77
#define HMF2500_ATTR_SYSTEM_SOFTWARE_VERSION                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 78
#define HMF2500_ATTR_SYSTEM_HARDWARE_NUMBER                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 79
#define HMF2500_ATTR_INSTRUMENT_NAME                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 80

// hmf2500_rngIntExt
#define HMF2500_VAL_INT                                                     0
#define HMF2500_VAL_EXT                                                     1

// hmf2500_rngOutputFunction
#define HMF2500_VAL_FUNC_SINE                                               0
#define HMF2500_VAL_FUNC_SQUARE                                             1
#define HMF2500_VAL_FUNC_RAMP                                               2
#define HMF2500_VAL_FUNC_PULSE                                              3
#define HMF2500_VAL_FUNC_ARB                                                4

// hmf2500_rngAmplitudeUnit
#define HMF2500_VAL_UNIT_V                                                  0
#define HMF2500_VAL_UNIT_DBM                                                1

// hmf2500_rngPolarity
#define HMF2500_VAL_NORMAL                                                  0
#define HMF2500_VAL_INVERTED                                                1

// hmf2500_rngSystemReference
#define HMF2500_VAL_REF_IMM                                                 0
#define HMF2500_VAL_REF_EXT                                                 1

// hmf2500_rngModulationFunction
#define HMF2500_VAL_FUNC_MOD_SINE                                           0
#define HMF2500_VAL_FUNC_MOD_SQUARE                                         1
#define HMF2500_VAL_FUNC_MOD_PRAMP                                          2
#define HMF2500_VAL_FUNC_MOD_NRAMP                                          3
#define HMF2500_VAL_FUNC_MOD_TRIANGLE                                       4
#define HMF2500_VAL_FUNC_MOD_WNO                                            5
#define HMF2500_VAL_FUNC_MOD_PNO                                            6
#define HMF2500_VAL_FUNC_MOD_CARD                                           7
#define HMF2500_VAL_FUNC_MOD_EXPR                                           8
#define HMF2500_VAL_FUNC_MOD_EXPF                                           9
#define HMF2500_VAL_FUNC_MOD_RAM                                            10

// hmf2500_rngLinLog
#define HMF2500_VAL_LIN                                                     0
#define HMF2500_VAL_LOG                                                     1

// hmf2500_rngBurstMode
#define HMF2500_VAL_BURST_TRIGGERED                                         0
#define HMF2500_VAL_BURST_GATED                                             1

// hmf2500_rngArbMedium
#define HMF2500_VAL_RAM                                                     0
#define HMF2500_VAL_ROM                                                     1

// hmf2500_rngArb
#define HMF2500_VAL_ARB1                                                    1
#define HMF2500_VAL_ARB2                                                    2
#define HMF2500_VAL_ARB3                                                    3
#define HMF2500_VAL_ARB4                                                    4

// hmf2500_rngTriggerSlope
#define HMF2500_VAL_TRIGGER_POS                                             0
#define HMF2500_VAL_TRIGGER_NEG                                             1

// hmf2500_rngSweepMarkerStyle
#define HMF2500_VAL_STYLE_NORMAL                                            0
#define HMF2500_VAL_STYLE_CURSOR                                            1
#define HMF2500_VAL_STYLE_PULSE                                             2

// hmf2500_rngLEDBrigthness
#define HMF2500_VAL_LOW                                                     0
#define HMF2500_VAL_HIGH                                                    1

// hmf2500_rngHardcopyFormat
#define HMF2500_VAL_FORMAT_BMP                                              0
#define HMF2500_VAL_FORMAT_GIF                                              1
#define HMF2500_VAL_FORMAT_PNG                                              2

// hmf2500_rngTriggerSlopeOutput
#define HMF2500_VAL_TRIGGER_OUTPUT_POS                                      0
#define HMF2500_VAL_TRIGGER_OUTPUT_NEG                                      1
/* END GENERATE */

/*****************************************************************************
 *- Hidden Attribute Declarations -------------------------------------------*
 *****************************************************************************/
/*
#define HMF2500_ATTR_OPC_TIMEOUT               (RS_ATTR_OPC_TIMEOUT)           
#define HMF2500_ATTR_IO_SESSION                (RS_ATTR_IO_SESSION)            
#define HMF2500_ATTR_OPC_CALLBACK              (RS_ATTR_OPC_CALLBACK)          
#define HMF2500_ATTR_CHECK_STATUS_CALLBACK     (RS_ATTR_CHECK_STATUS_CALLBACK) 
*/
/****************************************************************************
 *---------------- Constant definition  ------------------------------------*
 ****************************************************************************/

#define HMF2500_VAL_FUSE_LINK   0
#define HMF2500_VAL_FUSE_UNLINK 1

#define HMF2500_VAL_QUESTIONABLE_REGISTER 0
#define HMF2500_VAL_QUESTIONABLE_INSTRUMENT_REGISTER 1
#define HMF2500_VAL_QUESTIONABLE_INSTRUMENT_SPECIFIC_REGISTER 2 
#define HMF2500_VAL_QUESTIONABLE_INSTRUMENT_SPECIFIC_CONDITION_REGISTER 3
		
#define HMF2500_VAL_MEM_OPERATION_STORE  0
#define HMF2500_VAL_MEM_OPERATION_RECALL 1
#define HMF2500_VAL_MEM_OPERATION_CLEAR  2
	
#define HMF2500_VAL_COPY       0
#define HMF2500_VAL_DELETE     1	
#define HMF2500_VAL_DELETE_ALL 2
	
#define HMF2500_VAL_LOW	       0
#define HMF2500_VAL_HIGH	   1
	
#define	HMF2500_VAL_AM         0
#define	HMF2500_VAL_FM         1	
#define	HMF2500_VAL_PM         2
#define	HMF2500_VAL_PWM        3 

#define	HMF2500_VAL_CENT       0
#define	HMF2500_VAL_SPAN       1
#define	HMF2500_VAL_STAR       2
#define	HMF2500_VAL_STOP       3
	
#define	HMF2500_VAL_EDGE_RISE  0
#define	HMF2500_VAL_EDGE_FALL  1
/****************************************************************************
 *---------------- Instrument Driver Function Declarations -----------------*
 ****************************************************************************/

ViStatus _VI_FUNC hmf2500_init (ViRsrc resourceName, ViBoolean IDQuery,
                                ViBoolean resetDevice, ViSession* instrumentHandle);
ViStatus _VI_FUNC hmf2500_InitWithOptions (ViRsrc resourceName, ViBoolean IDQuery,
                                           ViBoolean resetDevice,
                                           ViString optionString,
                                           ViSession* instrumentHandle);
ViStatus _VI_FUNC hmf2500_ConfigureRF (ViSession instrumentHandle,
                                       ViReal64 frequency, ViReal64 powerLevel,
                                       ViInt32 amplitudeUnit,ViInt32 input);

ViStatus _VI_FUNC hmf2500_ConfigureOutputEnabled (ViSession instrumentHandle,
                                                  ViBoolean outputEnabled);

ViStatus _VI_FUNC hmf2500_ConfigurePowerLevelOffset (ViSession instrumentHandle,
                                                     ViBoolean powerLevel,
                                                     ViReal64 powerLevelOffset);

ViStatus _VI_FUNC hmf2500_ConfigurePowerLevelWithOffset (ViSession instrumentHandle,
	                                                     ViInt32 highLow,
                                                         ViReal64 powerLevelOffset); 
                                                         
ViStatus _VI_FUNC hmf2500_ConfigureSystemReference (ViSession instrumentHandle,
                                                    ViInt32 systemReference);

ViStatus _VI_FUNC hmf2500_ConfigureOutputFunction (ViSession instrumentHandle,
                                                   ViInt32 outputFunction);

ViStatus _VI_FUNC hmf2500_ConfigureOutput (ViSession instrumentHandle,
                                           ViInt32 outputLoad, ViInt32 polarity);

ViStatus _VI_FUNC hmf2500_ConfigureSquareDutyCycle (ViSession instrumentHandle,
                                                    ViReal64 squareDutyCycle);

ViStatus _VI_FUNC hmf2500_ConfigureSquareWidth (ViSession instrumentHandle,
                                                ViInt32 squareSide, ViReal64 width);

ViStatus _VI_FUNC hmf2500_ConfigureRampSymmetry (ViSession instrumentHandle,
                                                 ViReal64 rampSymmetry);

ViStatus _VI_FUNC hmf2500_ConfigureRampEdgeTime (ViSession instrumentHandle,
                                                 ViInt32 edge, ViReal64 time);

ViStatus _VI_FUNC hmf2500_ConfigurePulse (ViSession instrumentHandle,
	                                      ViInt32 highLow,
                                          ViReal64 pulseDutyCycle,
                                          ViReal64 pulseWidth,
                                          ViReal64 pulseEdgeTime
                                          );

ViStatus _VI_FUNC hmf2500_ConfigureTrigger (ViSession instrumentHandle,
                                            ViBoolean triggerEnabled,
                                            ViInt32 systemReference);

ViStatus _VI_FUNC hmf2500_ConfigureTriggerSlope (ViSession instrumentHandle,
                                                 ViInt32 triggerSlope,
                                                 ViInt32 outputTriggerSlope);

ViStatus _VI_FUNC hmf2500_SendSoftwareTrigger (ViSession instrumentHandle);

ViStatus _VI_FUNC hmf2500_ConfigureModulationShape (ViSession instrumentHandle,
	                                                ViInt32 modulation,
                                                    ViInt32 modulationShape);
                                                    

ViStatus _VI_FUNC hmf2500_ConfigureAM (ViSession instrumentHandle,
                                       ViBoolean AMEnabled, ViInt32 AMSource,
                                       ViReal64 AMDepth);

ViStatus _VI_FUNC hmf2500_ConfigureFM (ViSession instrumentHandle,
                                       ViBoolean FMEnabled, ViInt32 FMSource,
                                       ViReal64 FMDeviation);

ViStatus _VI_FUNC hmf2500_ConfigurePM (ViSession instrumentHandle,
                                       ViBoolean PMEnabled, ViInt32 PMSource,
                                       ViReal64 PMDeviation);

ViStatus _VI_FUNC hmf2500_ConfigurePWM (ViSession instrumentHandle,
                                        ViBoolean pulseEnabled,
                                        ViInt32 pulseSource,
                                        ViReal64 pulseModulationDutyCycle,
                                        ViReal64 internalFrequency);

ViStatus _VI_FUNC hmf2500_ConfigureFSKModulation (ViSession instrumentHandle,
                                                  ViBoolean FSKEnabled,
                                                  ViInt32 FSKSource,
                                                  ViReal64 FSKDutyCycle,
                                                  ViReal64 FSKFrequency,
                                                  ViReal64 FSKHop);

ViStatus _VI_FUNC hmf2500_ConfigureFrequencySweep (ViSession instrumentHandle,
                                                   ViInt32 sweep,
                                                   ViBoolean sweepEnabled,
                                                   ViReal64 sweepFrequency,
                                                   ViInt32 sweepSpacing,
                                                   ViReal64 sweepTime);

ViStatus _VI_FUNC hmf2500_ConfigureSweepMarker (ViSession instrumentHandle,
                                                ViBoolean sweepMarkerEnabled,
                                                ViReal64 sweepMarkerFrequency);

ViStatus _VI_FUNC hmf2500_ConfigureSweepMarkerStyle (ViSession instrumentHandle,
                                                     ViInt32 markerStyle);

ViStatus _VI_FUNC hmf2500_ConfigureBurst (ViSession instrumentHandle,
                                          ViBoolean burstEnabled,
                                          ViInt32 burstMode,
                                          ViInt32 burstNCycles,
                                          ViReal64 burstInternalPeriod,
                                          ViReal64 burstPhase);

ViStatus _VI_FUNC hmf2500_ConfigureDisplayTrace (ViSession instrumentHandle,
                                                 ViBoolean traceEnabled,
                                                 ViReal64 traceIntensity);

ViStatus _VI_FUNC hmf2500_ConfigureDisplay (ViSession instrumentHandle,
                                            ViReal64 grid,
											ViInt32 LEDBrigthness,
											ViReal64 backlight);





ViStatus _VI_FUNC hmf2500_ConfigureArbFunction (ViSession instrumentHandle,
                                                ViInt32 arbFunction);

ViStatus _VI_FUNC hmf2500_ConfigureArbData (ViSession instrumentHandle,
                                            ViInt32 arraySize, ViChar arbData[]);

ViStatus _VI_FUNC hmf2500_ConfigureArbDataModulation (ViSession instrumentHandle,
                                                      ViInt32 arraySize,
                                                      ViChar arbDataModulation[]);

ViStatus _VI_FUNC hmf2500_SaveArbData (ViSession instrumentHandle);
	
ViStatus _VI_FUNC hmf2500_SetAttributeViInt32 (ViSession instrumentHandle,
                                               ViString repeatedCapabilityName,
                                               ViUInt32 attributeID,
                                               ViInt32 attributeValue);
ViStatus _VI_FUNC hmf2500_SetAttributeViReal64 (ViSession instrumentHandle,
                                                ViString repeatedCapabilityName,
                                                ViUInt32 attributeID,
                                                ViReal64 attributeValue);
ViStatus _VI_FUNC hmf2500_SetAttributeViString (ViSession instrumentHandle,
                                                ViString repeatedCapabilityName,
                                                ViUInt32 attributeID,
                                                ViString attributeValue);
ViStatus _VI_FUNC hmf2500_SetAttributeViBoolean (ViSession instrumentHandle,
                                                 ViString repeatedCapabilityName,
                                                 ViUInt32 attributeID,
                                                 ViBoolean attributeValue);
ViStatus _VI_FUNC hmf2500_SetAttributeViSession (ViSession instrumentHandle,
                                                 ViString repeatedCapabilityName,
                                                 ViUInt32 attributeID,
                                                 ViSession attributeValue);

ViStatus _VI_FUNC hmf2500_GetAttributeRepeatedCapabilityIds
             (ViSession instrumentHandle, ViUInt32 attributeID, ViInt32 bufferSize,
              ViChar _VI_FAR repeatedCapabilityId_s[]);
ViStatus _VI_FUNC hmf2500_GetAttributeRepeatedCapabilityIdNames
             (ViSession instrumentHandle, ViUInt32 attributeID,
              ViString repeatedCapabilityId, ViInt32 bufferSize,
              ViChar _VI_FAR repeatedCapabilityIdName_s[]);
ViStatus _VI_FUNC hmf2500_GetAttributeViInt32 (ViSession instrumentHandle,
                                               ViString repeatedCapabilityName,
                                               ViUInt32 attributeID,
                                               ViInt32* attributeValue);
ViStatus _VI_FUNC hmf2500_GetAttributeViReal64 (ViSession instrumentHandle,
                                                ViString repeatedCapabilityName,
                                                ViUInt32 attributeID,
                                                ViReal64* attributeValue);
ViStatus _VI_FUNC hmf2500_GetAttributeViString (ViSession instrumentHandle,
                                                ViString repeatedCapabilityName,
                                                ViUInt32 attributeID,
                                                ViInt32 bufferSize,
                                                ViChar _VI_FAR attributeValue[]);
ViStatus _VI_FUNC hmf2500_GetAttributeViBoolean (ViSession instrumentHandle,
                                                 ViString repeatedCapabilityName,
                                                 ViUInt32 attributeID,
                                                 ViBoolean* attributeValue);
ViStatus _VI_FUNC hmf2500_GetAttributeViSession (ViSession instrumentHandle,
                                                 ViString repeatedCapabilityName,
                                                 ViUInt32 attributeID,
                                                 ViSession* attributeValue);
ViStatus _VI_FUNC hmf2500_CheckAttributeViInt32 (ViSession instrumentHandle,
                                                 ViString repeatedCapabilityName,
                                                 ViUInt32 attributeID,
                                                 ViInt32 attributeValue);
ViStatus _VI_FUNC hmf2500_CheckAttributeViReal64 (ViSession instrumentHandle,
                                                  ViString repeatedCapabilityName,
                                                  ViUInt32 attributeID,
                                                  ViReal64 attributeValue);
ViStatus _VI_FUNC hmf2500_CheckAttributeViString (ViSession instrumentHandle,
                                                  ViString repeatedCapabilityName,
                                                  ViUInt32 attributeID,
                                                  ViString attributeValue);
ViStatus _VI_FUNC hmf2500_CheckAttributeViBoolean (ViSession instrumentHandle,
                                                   ViString repeatedCapabilityName,
                                                   ViUInt32 attributeID,
                                                   ViBoolean attributeValue);
ViStatus _VI_FUNC hmf2500_CheckAttributeViSession (ViSession instrumentHandle,
                                                   ViString repeatedCapabilityName,
                                                   ViUInt32 attributeID,
                                                   ViSession attributeValue);

ViStatus _VI_FUNC hmf2500_ConfigureSystemSound (ViSession instrumentHandle,
                                                ViBoolean errorBeepEnabled,
                                                ViBoolean controlBeepEnabled);

ViStatus _VI_FUNC hmf2500_reset (ViSession instrumentHandle);
ViStatus _VI_FUNC hmf2500_self_test (ViSession instrumentHandle,
                                     ViInt16* selfTestResult,
                                     ViChar _VI_FAR selfTestMessage[]);
ViStatus _VI_FUNC hmf2500_revision_query (ViSession instrumentHandle,
                                          ViChar _VI_FAR instrumentDriverRevision[],
                                          ViChar _VI_FAR firmwareRevision[]);

ViStatus _VI_FUNC hmf2500_error_query (ViSession instrumentHandle,
                                       ViInt32* errorCode,
                                       ViChar _VI_FAR errorMessage[]);

ViStatus _VI_FUNC hmf2500_SystemInfo (ViSession instrumentHandle,
                                      ViChar serialNumber[],
                                      ViChar softwareVersion[],
                                      ViChar hardwareNumber[],
                                      ViChar instrumentName[]);

ViStatus _VI_FUNC hmf2500_QueryHardcopyData (ViSession instrumentHandle,
                                             ViUInt32 timeout, ViInt32 arraySize,
                                             ViChar data[],
                                             ViInt32 *returnedValues);

ViStatus _VI_FUNC hmf2500_ConfigureHardcopyFormat (ViSession instrumentHandle,
                                                   ViInt32 hardcopyFormat);
ViStatus _VI_FUNC hmf2500_QueryHardcopySize (ViSession instrumentHandle,
                                             ViInt32 *x, ViInt32 *y);

//ViStatus _VI_FUNC hmf2500_ErrorList (ViSession instrumentHandle, ViInt32 bufferSize,ViChar _VI_FAR errors[]);
ViStatus _VI_FUNC hmf2500_error_message (ViSession instrumentHandle,
                                         ViStatus errorCode,
                                         ViChar _VI_FAR errorMessage[]);


ViStatus _VI_FUNC hmf2500_GetError (ViSession instrumentHandle, ViStatus* code,
                                    ViInt32 bufferSize,
                                    ViChar _VI_FAR description[]);
ViStatus _VI_FUNC hmf2500_ClearError (ViSession instrumentHandle);
ViStatus _VI_FUNC hmf2500_WriteInstrData (ViSession instrumentHandle,
                                          ViString writeBuffer);
ViStatus _VI_FUNC hmf2500_ReadInstrData (ViSession instrumentHandle,
                                         ViInt32 numberOfBytesToRead,
                                         ViChar _VI_FAR readBuffer[],
                                         ViUInt32* numBytesRead);
ViStatus _VI_FUNC hmf2500_QueryViBoolean (ViSession instrumentHandle,
                                          ViString command, ViBoolean* value);
ViStatus _VI_FUNC hmf2500_QueryViInt32 (ViSession instrumentHandle,
                                        ViString command, ViInt32* value);
ViStatus _VI_FUNC hmf2500_QueryViReal64 (ViSession instrumentHandle,
                                         ViString command, ViReal64* value);
ViStatus _VI_FUNC hmf2500_QueryViString (ViSession instrumentHandle,
                                         ViString command, ViInt32 bufferSize,
                                         ViChar _VI_FAR value[]);
ViStatus _VI_FUNC hmf2500_close (ViSession instrumentHandle);

/****************************************************************************
 *------------------------ Error And Completion Codes ----------------------*
 ****************************************************************************/

#define HMF2500_WARN_MEASURE_UNCALIBRATED    (RS_CLASS_WARN_BASE + 0x0001L)
#define HMF2500_WARN_OVER_RANGE              (RS_CLASS_WARN_BASE + 0x0002L)

#define HMF2500_ERROR_INCORRECT_STATE        (RS_CLASS_ERROR_BASE + 0x0003L)
#define HMF2500_ERROR_INCORRECT_RESPONSE     (RS_CLASS_ERROR_BASE + 0x0002L)
#define HMF2500_ERROR_MAX_TIME_EXCEEDED      (RS_CLASS_ERROR_BASE + 0x0001L)

#define HMF2500_WARNMSG_MEASURE_UNCALIBRATED "Uncalibrated measurement"
#define HMF2500_WARNMSG_OVER_RANGE           "Measurement overrange"

#define HMF2500_ERRMSG_INCORRECT_STATE       "Instrument in incorrect state"
#define HMF2500_ERRMSG_INCORRECT_RESPONSE    "Response incorrect; report problem to HAMEG support!"
#define HMF2500_ERRMSG_MAX_TIME_EXCEEDED     "Max Time Exceeded"

#define HMF2500_ERROR_CODES_AND_MSGS \
    {HMF2500_ERROR_INCORRECT_STATE,   HMF2500_ERRMSG_INCORRECT_STATE},\
    {HMF2500_ERROR_INCORRECT_RESPONSE,     HMF2500_ERRMSG_INCORRECT_RESPONSE},\
    {HMF2500_ERROR_MAX_TIME_EXCEEDED,    HMF2500_ERRMSG_MAX_TIME_EXCEEDED}


/****************************************************************************
 *---------------------------- End Include File ----------------------------*
 ****************************************************************************/



ViStatus _VI_FUNC hmf2500_ConfigurePeriod (ViSession instrumentHandle,
                                           ViReal64 period);

#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif
#endif /* __HMF2500_HEADER */
